@@ -1,5 +1,3 @@
-#' @docType package
-#'
 #' @name areaplot-package
 #'
 #' @title Plot Stacked Areas and Confidence Bands as Filled Polygons
@@ -13,9 +11,9 @@
 #' \emph{Plot:}
 #' \tabular{ll}{
 #'   \code{\link{areaplot}} \tab stacked area\cr
-#'   \code{\link{confplot}} \tab confidence bands
+#'   \code{\link{confplot}} \tab confidence band
 #' }
 #'
 #' @author Arni Magnusson.
 
-NA
+"_PACKAGE"
