@@ -17,6 +17,8 @@
 #' @param add whether polygons should be added to an existing plot.
 #' @param xlab a label for x axis.
 #' @param ylab a label for y axis.
+#' @param border border color of polygon(s). The default is to draw borders in
+#'        the foreground color. Pass \code{NA} to omit borders.
 #' @param col fill color of polygon(s). The default is a vector of gray colors.
 #' @param legend a logical indicating whether a legend should be added, or a
 #'        vector of strings for the legend. This only applies when more than one
@@ -52,7 +54,7 @@
 #'
 #' # formula
 #' areaplot(Armed.Forces~Year, data=longley)
-#' areaplot(cbind(Armed.Forces,Unemployed)~Year, data=longley)
+#' areaplot(cbind(Unemployed,Armed.Forces)~Year, data=longley)
 #' areaplot(.~Year, data=longley)
 #' areaplot(circumference~age+Tree, Orange)
 #'
@@ -79,6 +81,16 @@
 #'          ylab="Killed or seriously injured")
 #' abline(v=1983+1/12, lty=3)
 #'
+#' # POSIXt and Date
+#' airquality$Time <- ISOdate(1973, airquality$Month, airquality$Day)
+#' airquality$Date <- as.Date(airquality$Time)
+#' areaplot(Wind~Time, airquality, col="skyblue")
+#' areaplot(Wind~Date, airquality, col="linen")
+#'
+#' # border=NA
+#' areaplot(circumference~age+Tree, Orange)
+#' areaplot(circumference~age+Tree, Orange, border=NA)
+#'
 #' # legend
 #' require(MASS)
 #' areaplot(table(Aids2$age, Aids2$sex), legend=TRUE, col=c(2,4))
@@ -103,8 +115,8 @@ areaplot <- function(x, ...)
 #' @export areaplot.default
 
 areaplot.default <- function(x, y=NULL, prop=FALSE, rev=FALSE, add=FALSE,
-                             xlab=NULL, ylab=NULL, col=NULL, legend=FALSE,
-                             args.legend=NULL, ...)
+                             xlab=NULL, ylab=NULL, border=NULL, col=NULL,
+                             legend=FALSE, args.legend=NULL, ...)
 {
   if(is.ts(x)) # ts/mts
   {
@@ -163,6 +175,8 @@ areaplot.default <- function(x, y=NULL, prop=FALSE, rev=FALSE, add=FALSE,
   if(is.null(ylab))
     ylab <- deparse(substitute(y))
 
+  if(anyDuplicated(x))
+    stop("duplicated values on x-axis are not allowed")
   y <- as.matrix(y)
   if(length(x) != nrow(y))
     stop("'x' and 'y' lengths differ")
@@ -171,15 +185,15 @@ areaplot.default <- function(x, y=NULL, prop=FALSE, rev=FALSE, add=FALSE,
   col <- rep(col, length.out=ncol(y))
   if(!rev)
   {
-    y <- as.matrix(rev(as.data.frame(y)))
+    y <- y[, ncol(y):1, drop=FALSE]
     col <- rev(col)
   }
   if(prop)
     y <- prop.table(y, 1)
   y <- t(rbind(0, apply(y, 1, cumsum)))
   na <- is.na(x) | apply(is.na(y), 1, any)
-  x <- x[!na][order(x[!na])]
-  y <- y[!na,][order(x[!na]),]
+  y <- y[!na,][order(x[!na]),]  # reorder y by x
+  x <- x[!na][order(x[!na])]    # reorder x last
 
   if(!add)
     suppressWarnings(matplot(x, y, type="n", xlab=xlab, ylab=ylab, ...))
@@ -187,7 +201,7 @@ areaplot.default <- function(x, y=NULL, prop=FALSE, rev=FALSE, add=FALSE,
   for(i in 1:(ncol(y)-1))
   {
     yy <- c(y[,i+1], rev(y[,i]))
-    suppressWarnings(polygon(xx, yy, col=col[i], ...))
+    suppressWarnings(polygon(xx, yy, border=border, col=col[i], ...))
   }
 
   if(is.logical(legend))
@@ -238,7 +252,8 @@ areaplot.formula <- function(formula, data, subset, na.action, xlab=NULL,
   if(ncol(mf[-1]) == 0 || ncol(mf[-1]) >= 3)
     stop("formula must specify 1 or 2 variables after the tilde")
   if(anyDuplicated(mf[-1]))
-    stop("duplicated values after the tilde - try another formula or subset")
+    stop("duplicated values on x-axis are not allowed")
+  x <- sort(unique(mf[[2]]))
   if(is.null(xlab))
     xlab <- names(mf)[2]
   if(is.matrix(mf[[1]]))
@@ -247,13 +262,14 @@ areaplot.formula <- function(formula, data, subset, na.action, xlab=NULL,
     if(ncol(mf[-1]) != 1)
       stop("formula with cbind() must specify 1 variable after the tilde")
     lhs <- mf[[1]]
-    rownames(lhs) <- mf[[ncol(mf)]]
-    areaplot.default(lhs, xlab=xlab, ylab=ylab, ...)
+    if(is.null(ylab))
+      ylab <- ""
+    areaplot.default(x, lhs, xlab=xlab, ylab=ylab, ...)
   }
   else
   {
     if(is.null(ylab))
       ylab <- names(mf)[1]
-    areaplot.default(xtabs(mf, addNA=TRUE), xlab=xlab, ylab=ylab, ...)
+    areaplot.default(x, xtabs(mf, addNA=TRUE), xlab=xlab, ylab=ylab, ...)
   }
 }
